import path from "path";
import fs from "fs";
import UserI from "../types/UserI";
import { ServerInfoI } from "../types/ServerInfoI";

interface ConfigControllerI {
  users: { name: string, value: UserI }[];
  usersInGame: UserI[];
  messageTime: number;
  inGameChat: string;
  serverInfo?: ServerInfoI;
  chatChannelId?: string;
}

export default class ConfigController {
  configPath = path.join(process.env.STORAGE || "/app/storage", "config.json")
  public usersInGame: UserI[] = [];
  public users: Map<string, UserI> = new Map<string, UserI>();
  public authCodes: Map<string, string> = new Map<string, string>();
  public chatChannelId: string = ""
  public inGameChat: string = "General"
  public messageTime: number = 0

  constructor() {
    this.load()
    setInterval(() => this.save(), 10000)
  }
  save() {
    const r: ConfigControllerI = {
      users: Array.from(this.users, ([name, value]) => ({ name, value })),
      chatChannelId: this.chatChannelId,
      messageTime: this.messageTime,
      inGameChat: this.inGameChat,
      usersInGame: this.usersInGame,
    }
    fs.writeFileSync(this.configPath, JSON.stringify(r))
  }
  load() {
    const r = {
      users: this.users,
      messageTime: this.messageTime,
    }
    if (!fs.existsSync(this.configPath)) {
      fs.writeFileSync(this.configPath, JSON.stringify(r))
    }
    try {
      const t: ConfigControllerI = JSON.parse(String(fs.readFileSync(this.configPath)))
      if (!!t?.users)
        this.users = new Map<string, UserI>(t.users.map(v => [v.name, v.value]))
      if (!!t?.usersInGame)
        this.usersInGame = t.usersInGame
      if (!!t?.messageTime)
        this.messageTime = t.messageTime
      if (!!t?.inGameChat)
        this.inGameChat = t.inGameChat
      if (!!t?.chatChannelId)
        this.chatChannelId = t.chatChannelId
    } catch (error) {
      console.log(error)
    }
  }
}